"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsonfile_1 = require("jsonfile");
const path = require("path");
const commands_1 = require("./cli/commands");
// tslint:disable-next-line no-var-requires
const caporal = require('caporal');
const pkg = JSON.parse(jsonfile_1.readFileSync(path.normalize(path.join(__dirname, '../package.json'))));
caporal
    .version(pkg.version)
    .description(pkg.description)
    .command('generate', 'generates a basic component of type widget, dashboard or job')
    .help('atlasboard generate widget mywidget')
    .argument('<component>', 'type of component', ['widget', 'dashboard', 'job'])
    .argument('<name>', 'name of component')
    .action((args, options, logger) => {
    logger.info('Command \'generate\' called with:');
    logger.info('arguments: %j', args);
    logger.info('options: %j', options);
    commands_1.generate(args, options, logger, (error) => {
        if (error) {
            throw Error(error);
        }
    });
})
    .command('new', 'generates a new dashboard project')
    .help('atlasboard new mywallboard')
    .argument('<app>', 'App to deploy', /^myapp|their-app$/)
    .argument('[env]', 'Environment to deploy on', /^dev|staging|production$/, 'local')
    .action((args, options, logger) => {
    logger.info('Command \'new\' called with:');
    logger.info('arguments: %j', args);
    logger.info('options: %j', options);
    commands_1.newProject(args, options, logger, (error) => {
        if (error) {
            throw Error(error);
        }
    });
})
    .command('list', 'lists all available components (widgets or jobs) among all packages')
    .help('status-board list')
    .action((args, options, logger) => {
    logger.info('Command \'list\' called with:');
    logger.info('arguments: %j', args);
    logger.info('options: %j', options);
    commands_1.list(args, options, logger, (error) => {
        if (error) {
            throw Error(error);
        }
    });
})
    .command('start', 'starts Status Board\'s server')
    .help('my help for the order command')
    .argument('[port]', 'runs atlasboard in port')
    .option('--noinstall', 'skips npm package install (faster startup)')
    .option('--job <job>', 'runs only jobs matching \'myjob\'')
    .option('--dashboard <dashboard>', 'loads only dashboards matching')
    .action((args, options, logger) => {
    logger.info('Command \'start\' called with:');
    logger.info('arguments: %j', args);
    logger.info('options: %j', options);
    commands_1.start(args, options, logger, (error) => {
        if (error) {
            throw Error(error);
        }
    });
})
    .command('install', 'install package dependencies')
    .help('status-board install')
    .action((args, options, logger) => {
    logger.info('Command \'install\' called with:');
    logger.info('arguments: %j', args);
    logger.info('options: %j', options);
    commands_1.install(args, options, logger, (error) => {
        if (error) {
            throw Error(error);
        }
    });
});
exports.default = caporal;
//# sourceMappingURL=caporal.js.map