"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const logger_1 = require("./logger");
function isPathContainedInRoot(pathDir, root) {
    if (typeof root !== 'string' || typeof pathDir !== 'string') {
        return false;
    }
    let pathDirCheck;
    if (pathDir[0] !== '/') {
        pathDirCheck = path.join(process.cwd(), pathDir);
    }
    else {
        pathDirCheck = pathDir;
    }
    return pathDirCheck.indexOf(root) === 0;
}
exports.isPathContainedInRoot = isPathContainedInRoot;
// tslint:disable-next-line no-shadowed-variable
function valid(path) {
    if (!path) {
        return false;
    }
    // In case it is another type, like number
    const pathToCheck = path.toString();
    let malicious = false;
    if ((pathToCheck.indexOf('/') !== -1) || (pathToCheck.indexOf('\\') !== -1)) {
        malicious = true;
    }
    if (pathToCheck.indexOf('..') !== -1) {
        malicious = true;
    }
    if (pathToCheck.indexOf('\0') !== -1) {
        malicious = true;
    }
    if (malicious) {
        logger_1.default().log('Malicious path detected: %s', pathToCheck);
        return false;
    }
    return true;
}
// -----------------------------------------
// Accepts a list of files or directory names
// Returns "" if invalid.
// -----------------------------------------
function areValidPathElements(paths) {
    const pathsToCheck = Array.isArray(paths) ? paths : [paths];
    return pathsToCheck.every(valid);
}
exports.areValidPathElements = areValidPathElements;
function getRndInt(min, max) {
    return Math.floor(Math.random() * (max - min + 1)) + min;
}
exports.getRndInt = getRndInt;
function readJSONFile(dashboardPath, cb) {
    fs.readFile(dashboardPath, (err, data) => {
        if (err) {
            return cb(err);
        }
        try {
            cb(null, JSON.parse(data.toString()));
        }
        catch (e) {
            cb(e);
        }
    });
}
exports.readJSONFile = readJSONFile;
// tslint:disable-next-line max-line-length no-shadowed-variable
function getJSONFromFile(path, defaultValue, warnIfFileNotExists, warnIfFileIsInvalid) {
    try {
        if (!fs.existsSync(path)) {
            if (warnIfFileNotExists) {
                warnIfFileNotExists(path);
            }
            return defaultValue;
        }
        return JSON.parse(fs.readFileSync(path).toString());
    }
    catch (e) {
        if (warnIfFileIsInvalid) {
            warnIfFileIsInvalid(path, e);
        }
        return defaultValue;
    }
}
exports.getJSONFromFile = getJSONFromFile;
//# sourceMappingURL=helpers.js.map